@@ -21,9 +21,11 @@
 #    misrepresented as being the original software.
 # 3. This notice may not be removed or altered from any source distribution.
 
-import zlib, datetime
+import datetime
 import unittest
 import pysqlite2.dbapi2 as sqlite
+import zlib
+
 
 class SqliteTypeTests(unittest.TestCase):
     def setUp(self):
@@ -39,39 +41,39 @@ class SqliteTypeTests(unittest.TestCase):
         self.cur.execute("insert into test(s) values (?)", (u"sterreich",))
         self.cur.execute("select s from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], u"sterreich")
+        self.assertEqual(row[0], u"sterreich")
 
     def CheckSmallInt(self):
         self.cur.execute("insert into test(i) values (?)", (42,))
         self.cur.execute("select i from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], 42)
+        self.assertEqual(row[0], 42)
 
     def CheckLargeInt(self):
         num = 2**40
         self.cur.execute("insert into test(i) values (?)", (num,))
         self.cur.execute("select i from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], num)
+        self.assertEqual(row[0], num)
 
     def CheckFloat(self):
         val = 3.14
         self.cur.execute("insert into test(f) values (?)", (val,))
         self.cur.execute("select f from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], val)
+        self.assertEqual(row[0], val)
 
     def CheckBlob(self):
         val = buffer("Guglhupf")
         self.cur.execute("insert into test(b) values (?)", (val,))
         self.cur.execute("select b from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], val)
+        self.assertEqual(row[0], val)
 
     def CheckUnicodeExecute(self):
         self.cur.execute(u"select 'sterreich'")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], u"sterreich")
+        self.assertEqual(row[0], u"sterreich")
 
     def CheckNonUtf8_Default(self):
         try:
@@ -149,14 +151,14 @@ class DeclTypesTests(unittest.TestCase):
         self.cur.execute("insert into test(s) values (?)", ("foo",))
         self.cur.execute('select s as "s [WRONG]" from test')
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], "foo")
+        self.assertEqual(row[0], "foo")
 
     def CheckSmallInt(self):
         # default
         self.cur.execute("insert into test(i) values (?)", (42,))
         self.cur.execute("select i from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], 42)
+        self.assertEqual(row[0], 42)
 
     def CheckLargeInt(self):
         # default
@@ -164,7 +166,7 @@ class DeclTypesTests(unittest.TestCase):
         self.cur.execute("insert into test(i) values (?)", (num,))
         self.cur.execute("select i from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], num)
+        self.assertEqual(row[0], num)
 
     def CheckFloat(self):
         # custom
@@ -172,20 +174,20 @@ class DeclTypesTests(unittest.TestCase):
         self.cur.execute("insert into test(f) values (?)", (val,))
         self.cur.execute("select f from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], 47.2)
+        self.assertEqual(row[0], 47.2)
 
     def CheckBool(self):
         # custom
         self.cur.execute("insert into test(b) values (?)", (False,))
         self.cur.execute("select b from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], False)
+        self.assertEqual(row[0], False)
 
         self.cur.execute("delete from test")
         self.cur.execute("insert into test(b) values (?)", (True,))
         self.cur.execute("select b from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], True)
+        self.assertEqual(row[0], True)
 
     def CheckUnicode(self):
         # default
@@ -193,14 +195,14 @@ class DeclTypesTests(unittest.TestCase):
         self.cur.execute("insert into test(u) values (?)", (val,))
         self.cur.execute("select u from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], val)
+        self.assertEqual(row[0], val)
 
     def CheckFoo(self):
         val = DeclTypesTests.Foo("bla")
         self.cur.execute("insert into test(foo) values (?)", (val,))
         self.cur.execute("select foo from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], val)
+        self.assertEqual(row[0], val)
 
     def CheckUnsupportedSeq(self):
         class Bar: pass
@@ -230,20 +232,20 @@ class DeclTypesTests(unittest.TestCase):
         self.cur.execute("insert into test(bin) values (?)", (val,))
         self.cur.execute("select bin from test")
         row = self.cur.fetchone()
-        self.failUnlessEqual(row[0], val)
+        self.assertEqual(row[0], val)
 
     def CheckNumber1(self):
         self.cur.execute("insert into test(n1) values (5)")
         value = self.cur.execute("select n1 from test").fetchone()[0]
         # if the converter is not used, it's an int instead of a float
-        self.failUnlessEqual(type(value), float)
+        self.assertEqual(type(value), float)
 
     def CheckNumber2(self):
         """Checks wether converter names are cut off at '(' characters"""
         self.cur.execute("insert into test(n2) values (5)")
         value = self.cur.execute("select n2 from test").fetchone()[0]
         # if the converter is not used, it's an int instead of a float
-        self.failUnlessEqual(type(value), float)
+        self.assertEqual(type(value), float)
 
 class ColNamesTests(unittest.TestCase):
     def setUp(self):
@@ -253,7 +255,7 @@ class ColNamesTests(unittest.TestCase):
 
         sqlite.converters["FOO"] = lambda x: "[%s]" % x
         sqlite.converters["BAR"] = lambda x: "<%s>" % x
-        sqlite.converters["EXC"] = lambda x: 5/0
+        sqlite.converters["EXC"] = lambda x: 5 // 0
         sqlite.converters["B1B1"] = lambda x: "MARKER"
 
     def tearDown(self):
@@ -272,28 +274,28 @@ class ColNamesTests(unittest.TestCase):
         self.cur.execute("insert into test(x) values (?)", ("xxx",))
         self.cur.execute("select x from test")
         val = self.cur.fetchone()[0]
-        self.failUnlessEqual(val, "xxx")
+        self.assertEqual(val, "xxx")
 
     def CheckNone(self):
         self.cur.execute("insert into test(x) values (?)", (None,))
         self.cur.execute("select x from test")
         val = self.cur.fetchone()[0]
-        self.failUnlessEqual(val, None)
+        self.assertEqual(val, None)
 
     def CheckColName(self):
         self.cur.execute("insert into test(x) values (?)", ("xxx",))
         self.cur.execute('select x as "x [bar]" from test')
         val = self.cur.fetchone()[0]
-        self.failUnlessEqual(val, "<xxx>")
+        self.assertEqual(val, "<xxx>")
 
         # Check if the stripping of colnames works. Everything after the first
         # whitespace should be stripped.
-        self.failUnlessEqual(self.cur.description[0][0], "x")
+        self.assertEqual(self.cur.description[0][0], "x")
 
     def CheckCaseInConverterName(self):
         self.cur.execute("""select 'other' as "x [b1b1]\"""")
         val = self.cur.fetchone()[0]
-        self.failUnlessEqual(val, "MARKER")
+        self.assertEqual(val, "MARKER")
 
     def CheckCursorDescriptionNoRow(self):
         """
@@ -325,7 +327,7 @@ class ObjectAdaptationTests(unittest.TestCase):
     def CheckCasterIsUsed(self):
         self.cur.execute("select ?", (4,))
         val = self.cur.fetchone()[0]
-        self.failUnlessEqual(type(val), float)
+        self.assertEqual(type(val), float)
 
 class BinaryConverterTests(unittest.TestCase):
     def convert(s):
@@ -342,7 +344,7 @@ class BinaryConverterTests(unittest.TestCase):
     def CheckBinaryInputForConverter(self):
         testdata = "abcdefg" * 10
         result = self.con.execute('select ? as "x [bin]"', (buffer(zlib.compress(testdata)),)).fetchone()[0]
-        self.failUnlessEqual(testdata, result)
+        self.assertEqual(testdata, result)
 
 class DateTimeTests(unittest.TestCase):
     def setUp(self):
@@ -359,14 +361,14 @@ class DateTimeTests(unittest.TestCase):
         self.cur.execute("insert into test(d) values (?)", (d,))
         self.cur.execute("select d from test")
         d2 = self.cur.fetchone()[0]
-        self.failUnlessEqual(d, d2)
+        self.assertEqual(d, d2)
 
     def CheckSqliteTimestamp(self):
         ts = sqlite.Timestamp(2004, 2, 14, 7, 15, 0)
         self.cur.execute("insert into test(ts) values (?)", (ts,))
         self.cur.execute("select ts from test")
         ts2 = self.cur.fetchone()[0]
-        self.failUnlessEqual(ts, ts2)
+        self.assertEqual(ts, ts2)
 
     def CheckSqlTimestamp(self):
         # The date functions are only available in SQLite version 3.1 or later
@@ -378,22 +380,22 @@ class DateTimeTests(unittest.TestCase):
         self.cur.execute("insert into test(ts) values (current_timestamp)")
         self.cur.execute("select ts from test")
         ts = self.cur.fetchone()[0]
-        self.failUnlessEqual(type(ts), datetime.datetime)
-        self.failUnlessEqual(ts.year, now.year)
+        self.assertEqual(type(ts), datetime.datetime)
+        self.assertEqual(ts.year, now.year)
 
     def CheckDateTimeSubSeconds(self):
         ts = sqlite.Timestamp(2004, 2, 14, 7, 15, 0, 500000)
         self.cur.execute("insert into test(ts) values (?)", (ts,))
         self.cur.execute("select ts from test")
         ts2 = self.cur.fetchone()[0]
-        self.failUnlessEqual(ts, ts2)
+        self.assertEqual(ts, ts2)
 
     def CheckDateTimeSubSecondsFloatingPoint(self):
         ts = sqlite.Timestamp(2004, 2, 14, 7, 15, 0, 510241)
         self.cur.execute("insert into test(ts) values (?)", (ts,))
         self.cur.execute("select ts from test")
         ts2 = self.cur.fetchone()[0]
-        self.failUnlessEqual(ts, ts2)
+        self.assertEqual(ts, ts2)
 
 def suite():
     sqlite_type_suite = unittest.makeSuite(SqliteTypeTests, "Check")
